@@ -9,8 +9,8 @@ use Devel::Trepan::DB::Sub;
 
 package Devel::Trepan::CmdProcessor::Command::Break;
 use English qw( -no_match_vars );
-use if !defined @ISA, Devel::Trepan::CmdProcessor::Command;
-unless (defined(@ISA)) {
+use if !@ISA, Devel::Trepan::CmdProcessor::Command;
+unless (@ISA) {
     eval <<'EOE';
     use constant ALIASES    => qw(b);
     use constant CATEGORY   => 'breakpoints';
