@@ -9,8 +9,8 @@ use rlib '../../../..';
 #
 # NOTE: The enable command  subclasses this, so beware when changing! 
 package Devel::Trepan::CmdProcessor::Command::Enable;
-use if !defined @ISA, Devel::Trepan::CmdProcessor::Command ;
-unless (defined @ISA) {
+use if !@ISA, Devel::Trepan::CmdProcessor::Command ;
+unless (@ISA) {
     eval <<"EOE";
 use constant CATEGORY => 'breakpoints';
 use constant SHORT_HELP => 'Enable some breakpoints';
