@@ -8,9 +8,9 @@ use rlib '../../../..';
 
 package Devel::Trepan::CmdProcessor::Command::TBreak;
 
-use if !defined @ISA, Devel::Trepan::CmdProcessor::Command ;
+use if !@ISA, Devel::Trepan::CmdProcessor::Command ;
 
-unless (defined(@ISA)) {
+unless (@ISA) {
     eval <<'EOE';
 use constant CATEGORY => 'breakpoints';
 use constant SHORT_HELP => 'Set a one-time breakpoint';
