@@ -6,9 +6,9 @@ use rlib '../../../..';
 package Devel::Trepan::CmdProcessor::Command::Undisplay;
 use English qw( -no_match_vars );
 
-use if !defined @ISA, Devel::Trepan::CmdProcessor::Command ;
+use if !@ISA, Devel::Trepan::CmdProcessor::Command ;
 
-unless (defined @ISA) {
+unless (@ISA) {
     eval <<'EOE';
 use constant CATEGORY   => 'data';
 use constant NEED_STACK => 0;;
