@@ -6,9 +6,9 @@ use rlib '../../../..';
 use Exporter;
 # NOTE: The down command  subclasses this, so beware when changing! 
 package Devel::Trepan::CmdProcessor::Command::Up;
-use if !defined @ISA, Devel::Trepan::CmdProcessor::Command ;
+use if !@ISA, Devel::Trepan::CmdProcessor::Command ;
 
-unless (defined(@ISA)) {
+unless (@ISA) {
     eval <<'EOE';
 use constant ALIASES    => qw(u);
 use constant CATEGORY   => 'stack';
