@@ -1,4 +1,4 @@
-# Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011, 2012 Rocky Bernstein <rocky@cpan.org>
 use strict;
 use Exporter;
 use warnings;
@@ -33,6 +33,7 @@ our $EVENT2ICON = {
 sub canonic_file($$;$)
 {
     my ($self, $filename, $resolve) = @_;
+    return undef unless defined $filename;
     $resolve = 1 unless defined $resolve;
 
     # For now we want resolved filenames 
@@ -40,7 +41,8 @@ sub canonic_file($$;$)
 	my $is_eval = DB::LineCache::filename_is_eval($filename);
 	return $is_eval ? $filename : (basename($filename) || $filename);
     } elsif ($resolve) {
-    	$filename = DB::LineCache::map_file($filename);
+    	my $mapped_filename = DB::LineCache::map_file($filename);
+	$filename = $mapped_filename if defined($mapped_filename);
 	my $is_eval = DB::LineCache::filename_is_eval($filename);
 	return $is_eval ? $filename : (abs_path($filename) || $filename);
     } else {
@@ -77,30 +79,6 @@ sub resolve_file_with_dir($$)
     return undef;
 }
   
-# # Get line +line_number+ from file named +filename+. Return "\n"
-# # there was a problem. Leading blanks are stripped off.
-# sub line_at(filename, line_number, 
-# 	    opts = {
-#                 :reload_on_change => @settings[:reload],
-#                 :output => @settings[:highlight]
-# 	    })
-#     # We use linecache first to give precidence to user-remapped
-#     # file names
-#     line = LineCache::getline(filename, line_number, opts)
-#     unless line
-#       # Try using search directories (set with command "directory")
-#       if filename[0..0] != File::SEPARATOR
-#         try_filename = resolve_file_with_dir(filename) 
-#         if try_filename && 
-#             line = LineCache::getline(try_filename, line_number, opts) 
-#           LineCache::remap_file(filename, try_filename)
-#         }
-#       }
-#     }
-#     return nil unless line
-#     return line.lstrip.chomp
-#   }
-
 sub text_at($;$) 
 {
     my ($self, $opts) = @_;
@@ -173,6 +151,7 @@ sub source_location_info($)
     #  else
     my $filename = $self->filename();
     my $line_number = $self->line() || 0;
+
     if (DB::LineCache::filename_is_eval($filename)) {
     	if ($DB::filename eq $filename) {
 	    # Some lines in @DB::line might not be defined.
@@ -188,6 +167,9 @@ sub source_location_info($)
     }
     $canonic_filename = $self->canonic_file($filename, 0);
     return "${canonic_filename}:${line_number}";
+    # my $cop = 0;
+    # $cop = 0 + $DB::dbline[$line_number] if defined $DB::dbline[$line_number];
+    # return sprintf "${canonic_filename}:${line_number} 0x%x", $cop;
 } 
 
 unless (caller()) {
