@@ -11,8 +11,8 @@ use rlib '../../..';
 
 package Devel::Trepan::Interface::Script;
 our (@ISA);
-use if !defined(@ISA), Devel::Trepan::Interface;
-use if !defined(@ISA), Devel::Trepan::Interface::ComCodes;
+use if !@ISA, Devel::Trepan::Interface;
+use if !@ISA, Devel::Trepan::Interface::ComCodes;
 use Devel::Trepan::IO::Input;
 use Devel::Trepan::IO::StringArray;
 use Devel::Trepan::Util qw(hash_merge);
